@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import dataclasses
+import warnings
 
 """
 Flask-Limiter Extension
@@ -309,8 +310,17 @@ class Limiter:
 
         self._storage_options.update(config.get(ConfigVars.STORAGE_OPTIONS, {}))
         storage_uri_from_config = config.get(
-            ConfigVars.STORAGE_URI, config.get(ConfigVars.STORAGE_URL, "memory://")
+            ConfigVars.STORAGE_URI, config.get(ConfigVars.STORAGE_URL, None)
         )
+        if not storage_uri_from_config:
+            if not self._storage_uri:
+                warnings.warn(
+                    "Using the in-memory storage for tracking rate limits as no storage "
+                    "was explicitly specified. This is not recommended for production use. "
+                    "See: https://flask-limiter.readthedocs.io#configuring-a-storage-backend "
+                    "for documentation about configuring the storage backend."
+                )
+            storage_uri_from_config = "memory://"
         self._storage = cast(
             Storage,
             storage_from_string(
@@ -787,10 +797,17 @@ class Limiter:
         return self.context.view_rate_limits
 
     def __check_conditional_deductions(self, response: flask.wrappers.Response) -> None:
-
         for lim, args in self.context.conditional_deductions.items():
             if lim.deduct_when and lim.deduct_when(response):
-                self.limiter.hit(lim.limit, *args, cost=lim.cost)
+                try:
+                    self.limiter.hit(lim.limit, *args, cost=lim.cost)
+                except Exception as err:
+                    if self._swallow_errors:
+                        self.logger.exception(
+                            "Failed to deduct rate limit. " "Swallowing error"
+                        )
+                    else:
+                        raise err
 
     def __inject_headers(
         self, response: flask.wrappers.Response
